@@ -14,7 +14,7 @@
 #  limitations under the License.
 
 from elements import *
-import diagparser
+import parser
 from blockdiag.utils import XY
 from blockdiag.utils.collections import namedtuple
 
@@ -65,7 +65,7 @@ class DiagramTreeBuilder:
 
     def instantiate(self, network, group, tree):
         for stmt in tree.stmts:
-            if isinstance(stmt, diagparser.Node):
+            if isinstance(stmt, parser.Node):
                 node = DiagramNode.get(stmt.id)
                 node.set_attributes(network, stmt.attrs)
 
@@ -87,7 +87,7 @@ class DiagramTreeBuilder:
                 if node not in self.diagram.nodes:
                     self.diagram.nodes.append(node)
 
-            elif isinstance(stmt, diagparser.Network):
+            elif isinstance(stmt, parser.Network):
                 subnetwork = Network.get(stmt.id)
                 subnetwork.label = stmt.id
 
@@ -96,14 +96,14 @@ class DiagramTreeBuilder:
 
                 substmt = namedtuple('Statements', 'stmts')([])
                 for s in stmt.stmts:
-                    if isinstance(s, diagparser.DefAttrs):
+                    if isinstance(s, parser.DefAttrs):
                         subnetwork.set_attributes(s.attrs)
                     else:
                         substmt.stmts.append(s)
 
                 self.instantiate(subnetwork, group, substmt)
 
-            elif isinstance(stmt, diagparser.SubGraph):
+            elif isinstance(stmt, parser.SubGraph):
                 subgroup = NodeGroup.get(stmt.id)
 
                 if subgroup not in self.diagram.groups:
@@ -111,14 +111,14 @@ class DiagramTreeBuilder:
 
                 substmt = namedtuple('Statements', 'stmts')([])
                 for s in stmt.stmts:
-                    if isinstance(s, diagparser.DefAttrs):
+                    if isinstance(s, parser.DefAttrs):
                         subgroup.set_attributes(s.attrs)
                     else:
                         substmt.stmts.append(s)
 
                 self.instantiate(network, subgroup, substmt)
 
-            elif isinstance(stmt, diagparser.Edge):
+            elif isinstance(stmt, parser.Edge):
                 nodes = [DiagramNode.get(n) for n in stmt.nodes]
                 for node in nodes:
                     if node.group is None:
@@ -136,20 +136,20 @@ class DiagramTreeBuilder:
                     if nw:
                         self.diagram.networks.append(nw)
 
-            elif isinstance(stmt, diagparser.Route):
+            elif isinstance(stmt, parser.Route):
                 nodes = [DiagramNode.get(n) for n in stmt.nodes]
                 for node1, node2 in zip(nodes[:-1], nodes[1:]):
                     route = Route(node1, node2)
                     route.set_attributes(stmt.attrs)
                     self.diagram.routes.append(route)
 
-            elif isinstance(stmt, diagparser.DefAttrs):
+            elif isinstance(stmt, parser.DefAttrs):
                 self.diagram.set_attributes(stmt.attrs)
 
-            elif isinstance(stmt, diagparser.AttrPlugin):
+            elif isinstance(stmt, parser.AttrPlugin):
                 self.diagram.set_plugin(stmt.name, stmt.attrs)
 
-            elif isinstance(stmt, diagparser.AttrClass):
+            elif isinstance(stmt, parser.AttrClass):
                 name = unquote(stmt.name)
                 Diagram.classes[name] = stmt
 
@@ -174,7 +174,7 @@ class DiagramLayoutManager:
         networks = self.diagram.networks
 
         if group:
-            nodes = (n for n in self.diagram.nodes  if n.group == group)
+            nodes = (n for n in self.diagram.nodes if n.group == group)
         else:
             nodes = self.diagram.nodes
 
@@ -182,7 +182,7 @@ class DiagramLayoutManager:
             if node.layouted:
                 continue
 
-            joined = [g for g in node.networks if g.hidden == False]
+            joined = [g for g in node.networks if g.hidden is False]
             y1 = min(networks.index(g) for g in node.networks)
             if joined:
                 y2 = max(networks.index(g) for g in joined)
@@ -194,7 +194,7 @@ class DiagramLayoutManager:
             else:
                 nw = [n for n in node.networks if n.xy.y == y1][0]
                 nodes = [n for n in self.diagram.nodes if nw in n.networks]
-                layouted = [n for n in nodes  if n.xy.x > 0]
+                layouted = [n for n in nodes if n.xy.x > 0]
 
                 starts = 0
                 if layouted:
@@ -205,7 +205,7 @@ class DiagramLayoutManager:
                     if basenode.xy.y == y1:
                         starts = basenode.xy.x + 1
                     elif commonnw and \
-                         list(commonnw)[0].hidden == True:
+                         list(commonnw)[0].hidden is True:
                         starts = basenode.xy.x
                     else:
                         starts = basenode.xy.x + 1 - len(nodes)
@@ -237,7 +237,7 @@ class DiagramLayoutManager:
 
     def set_network_size(self):
         for network in self.diagram.networks:
-            nodes = [n for n in self.diagram.nodes  if network in n.networks]
+            nodes = [n for n in self.diagram.nodes if network in n.networks]
             nodes.sort(lambda a, b: cmp(a.xy.x, b.xy.x))
 
             x0 = min(n.xy.x for n in nodes)
@@ -277,13 +277,13 @@ class ScreenNodeBuilder:
     @classmethod
     def update_network_status(klass, diagram):
         for node in diagram.nodes:
-            above = [nw for nw in node.networks  if nw.xy.y <= node.xy.y]
-            if len(above) > 1 and [nw for nw in above  if nw.hidden]:
+            above = [nw for nw in node.networks if nw.xy.y <= node.xy.y]
+            if len(above) > 1 and [nw for nw in above if nw.hidden]:
                 for nw in above:
                     nw.hidden = False
 
-            below = [nw for nw in node.networks  if nw.xy.y > node.xy.y]
-            if len(below) > 1 and [nw for nw in below  if nw.hidden]:
+            below = [nw for nw in node.networks if nw.xy.y > node.xy.y]
+            if len(below) > 1 and [nw for nw in below if nw.hidden]:
                 for nw in below:
                     nw.hidden = False
 
